Snapshot

Struct Snapshot 

pub struct Snapshot { /* private fields */ }
A portable snapshot of the MDC.

Implementations

Source

impl Snapshot

pub fn new() -> Self

Returns a new, empty snapshot.

pub fn safe(&self) -> &Map

Returns a shared reference to the safe entries in the snapshot.

pub fn safe_mut(&mut self) -> &mut Map

Returns a mutable reference to the safe entries in the snapshot.

pub fn unsafe_(&self) -> &Map

Returns a shared reference to the unsafe entries in the snapshot.

pub fn unsafe_mut(&mut self) -> &mut Map

Returns a shared reference to the unsafe entries in the snapshot.