pub struct Snapshot { /* private fields */ }Expand description
A portable snapshot of the MDC.
Implementations
Sourceimpl Snapshot
impl Snapshot
Sourcepub fn safe_mut(&mut self) -> &mut Map
pub fn safe_mut(&mut self) -> &mut Map
Returns a mutable reference to the safe entries in the snapshot.
Sourcepub fn unsafe_(&self) -> &Map
pub fn unsafe_(&self) -> &Map
Returns a shared reference to the unsafe entries in the snapshot.
Sourcepub fn unsafe_mut(&mut self) -> &mut Map
pub fn unsafe_mut(&mut self) -> &mut Map
Returns a shared reference to the unsafe entries in the snapshot.